@@ -24,6 +24,7 @@ import org.locationtech.jts.geom.Geometry;
 import org.locationtech.jts.geom.LineString;
 import org.locationtech.jts.geom.Point;
 import org.locationtech.jts.geom.Polygon;
+import org.locationtech.jts.io.ParseException;
 import org.opengis.referencing.FactoryException;
 import org.opengis.referencing.crs.CoordinateReferenceSystem;
 
@@ -37,6 +38,7 @@ import static org.apache.flink.table.api.Expressions.call;
 import static org.junit.Assert.*;
 
 public class FunctionTest extends TestBase{
+
     @BeforeClass
     public static void onceExecutedBeforeAll() {
         initialize();
@@ -51,6 +53,15 @@ public class FunctionTest extends TestBase{
         assertEquals(1.0, result, 0);
     }
 
+    @Test
+    public void testAreaSpheroid() {
+        Table tbl = tableEnv.sqlQuery(
+                "SELECT ST_AreaSpheroid(ST_GeomFromWKT('Polygon ((35 34, 30 28, 34 25, 35 34))'))");
+        Double expected = 201824850811.76245;
+        Double actual = (Double) first(tbl).getField(0);
+        assertEquals(expected, actual, 0.1);
+    }
+
     @Test
     public void testAzimuth() {
         Table pointTable = tableEnv.sqlQuery("SELECT ST_Azimuth(ST_GeomFromWKT('POINT (0 0)'), ST_GeomFromWKT('POINT (1 1)'))");
@@ -151,6 +162,33 @@ public class FunctionTest extends TestBase{
         assertEquals(0.0, first(pointTable).getField(0));
     }
 
+    @Test
+    public void testDistanceSpheroid() {
+        Table tbl = tableEnv.sqlQuery(
+                "SELECT ST_DistanceSpheroid(ST_GeomFromWKT('POINT (51.3168 -0.56)'), ST_GeomFromWKT('POINT (55.9533 -3.1883)'))");
+        Double expected = 544430.9411996207;
+        Double actual = (Double) first(tbl).getField(0);
+        assertEquals(expected, actual, 0.1);
+    }
+
+    @Test
+    public void testDistanceSphere() {
+        Table tbl = tableEnv.sqlQuery(
+                "SELECT ST_DistanceSphere(ST_GeomFromWKT('POINT (51.3168 -0.56)'), ST_GeomFromWKT('POINT (55.9533 -3.1883)'))");
+        Double expected = 543796.9506134904;
+        Double actual = (Double) first(tbl).getField(0);
+        assertEquals(expected, actual, 0.1);
+    }
+
+    @Test
+    public void testDistanceSphereWithRadius() {
+        Table tbl = tableEnv.sqlQuery(
+                "SELECT ST_DistanceSphere(ST_GeomFromWKT('POINT (51.3168 -0.56)'), ST_GeomFromWKT('POINT (55.9533 -3.1883)'), 6378137.0)");
+        Double expected = 544405.4459192449;
+        Double actual = (Double) first(tbl).getField(0);
+        assertEquals(expected, actual, 0.1);
+    }
+
     @Test
     public void test3dDistance() {
         Table pointTable = tableEnv.sqlQuery("SELECT ST_3DDistance(ST_GeomFromWKT('POINT (0 0 0)'), ST_GeomFromWKT('POINT (1 1 1)'))");
@@ -166,6 +204,15 @@ public class FunctionTest extends TestBase{
         assertEquals(4, result, 0);
     }
 
+    @Test
+    public void testLengthSpheroid() {
+        Table tbl = tableEnv.sqlQuery(
+                "SELECT ST_LengthSpheroid(ST_GeomFromWKT('Polygon ((0 0, 0 90, 0 0))'))");
+        Double expected = 20037508.342789244;
+        Double actual = (Double) first(tbl).getField(0);
+        assertEquals(expected, actual, 0.1);
+    }
+
     @Test
     public void testYMax() {
         Table polygonTable = createPolygonTable(1);
@@ -614,4 +661,79 @@ public class FunctionTest extends TestBase{
         assertEquals(1, count(joinCleanedTable));
         assertEquals(2, first(joinCleanedTable).getField(1));
     }
+
+    @Test
+    public void testGeometricMedian() throws ParseException {
+        Table pointTable = tableEnv.sqlQuery("SELECT ST_GeometricMedian(ST_GeomFromWKT('MULTIPOINT((0 0), (1 1), (2 2), (200 200))'))");
+        Geometry expected = wktReader.read("POINT (1.9761550281255005 1.9761550281255005)");
+        Geometry actual = (Geometry) first(pointTable).getField(0);
+        assertEquals(String.format("expected: %s was %s", expected.toText(), actual != null ? actual.toText() : "null"),
+                0, expected.compareTo(actual, COORDINATE_SEQUENCE_COMPARATOR));
+    }
+
+    @Test
+    public void testGeometricMedianParamsTolerance() throws ParseException {
+        Table pointTable = tableEnv.sqlQuery(
+                "SELECT ST_GeometricMedian(ST_GeomFromWKT('MULTIPOINT ((0 0), (1 1), (0 1), (2 2))'), 1e-5)");
+        Geometry expected = wktReader.read("POINT (0.996230268436779 0.9999899629155288)");
+        Geometry actual = (Geometry) first(pointTable).getField(0);
+        assertEquals(String.format("expected: %s was %s", expected.toText(), actual != null ? actual.toText() : "null"),
+                0, expected.compareTo(actual, COORDINATE_SEQUENCE_COMPARATOR));
+    }
+
+    @Test
+    public void testGeometricMedianParamsFull() throws ParseException {
+        Table pointTable = tableEnv.sqlQuery(
+                "SELECT ST_GeometricMedian(ST_GeomFromWKT('MULTIPOINT ((0 0), (1 1), (0 1), (2 2))'), 1e-5, 10, false)");
+        Geometry expected = wktReader.read("POINT (0.8844442206215307 0.9912184073718183)");
+        Geometry actual = (Geometry) first(pointTable).getField(0);
+        assertEquals(String.format("expected: %s was %s", expected.toText(), actual != null ? actual.toText() : "null"),
+                0, expected.compareTo(actual, COORDINATE_SEQUENCE_COMPARATOR));
+    }
+
+    @Test
+    public void testNumPoints() {
+        Integer expected = 3;
+        Table pointTable = tableEnv.sqlQuery("SELECT ST_NumPoints(ST_GeomFromWKT('LINESTRING(0 1, 1 0, 2 0)'))");
+        Integer actual =  (Integer) first(pointTable).getField(0);
+        assertEquals(expected, actual);
+    }
+
+    @Test
+    public void testForce3D() {
+        Integer expectedDims = 3;
+        Table pointTable = tableEnv.sqlQuery("SELECT ST_Force3D(ST_GeomFromWKT('LINESTRING(0 1, 1 0, 2 0)'), 1.2) " +
+                                                "AS " + polygonColNames[0]);
+        pointTable = pointTable.select(call(Functions.ST_NDims.class.getSimpleName(), $(polygonColNames[0])));
+        Integer actual = (Integer) first(pointTable).getField(0);
+        assertEquals(expectedDims, actual);
+    }
+
+    @Test
+    public void testForce3DDefaultValue() {
+        Integer expectedDims = 3;
+        Table pointTable = tableEnv.sqlQuery("SELECT ST_Force3D(ST_GeomFromWKT('LINESTRING(0 1, 1 0, 2 0)')) " +
+                "AS " + polygonColNames[0]);
+        pointTable = pointTable.select(call(Functions.ST_NDims.class.getSimpleName(), $(polygonColNames[0])));
+        Integer actual = (Integer) first(pointTable).getField(0);
+        assertEquals(expectedDims, actual);
+    }
+
+    @Test
+    public void testNRings() {
+        Integer expected = 1;
+        Table pointTable = tableEnv.sqlQuery("SELECT ST_NRings(ST_GeomFromWKT('POLYGON ((1 0, 1 1, 2 1, 2 0, 1 0))'))");
+        Integer actual =  (Integer) first(pointTable).getField(0);
+        assertEquals(expected, actual);
+    }
+
+    @Test
+    public void testTranslate() {
+        Table polyTable = tableEnv.sqlQuery("SELECT ST_Translate(ST_GeomFromWKT('POLYGON ((1 0, 1 1, 2 1, 2 0, 1 0))'), 2, 5)" + "AS " + polygonColNames[0]);
+        polyTable = polyTable.select(call(Functions.ST_AsText.class.getSimpleName(), $(polygonColNames[0])));
+        String expected = "POLYGON ((3 5, 3 6, 4 6, 4 5, 3 5))";
+        String actual = (String) first(polyTable).getField(0);
+        assertEquals(expected, actual);
+    }
+
 }
